nx.ui.nx.Env - Next UI Toolkit

#

API Docs for: trial
Show: Inherited Protected Private Deprecated

# nx.ui.nx.Env Class

Module: nx.ui

Environment and check behavior support

## Constructor

### `nx.ui.nx.Env`

()

- Index
- Methods
- Properties

## Item Index

### Methods

- getSupportMap
- registerSupport
- support

### Properties

- browser
- compatMode
- documentMode
- engine
- keyMap
- os
- prefix
- strict
- strict
- userAgent

## Methods

### `getSupportMap`

() AddEventListener: boolean, dispatchEvent: boolean, getBoundingClientRect: boolean, onmousewheel: boolean, XDomainRequest: boolean, crossDomain: boolean, getComputedStyle: boolean, iePropertyChange: boolean, w3cChange: boolean, w3cFocus: boolean, w3cInput: boolean, innerText: boolean, firstElementChild: boolean, cssFloat: boolean, opacity: boolean, filter: boolean, removeProperty: boolean

Support map for debug

#### Returns:

AddEventListener: boolean, dispatchEvent: boolean, getBoundingClientRect: boolean, onmousewheel: boolean, XDomainRequest: boolean, crossDomain: boolean, getComputedStyle: boolean, iePropertyChange: boolean, w3cChange: boolean, w3cFocus: boolean, w3cInput: boolean, innerText: boolean, firstElementChild: boolean, cssFloat: boolean, opacity: boolean, filter: boolean, removeProperty: boolean:

}

### `registerSupport`

(

- `inName`
- `inValue`

)

Register a support item

#### Parameters:

- `inName` Object
- `inValue` Object

### `support`

(

- `inName`

)

Whether the property is support

#### Parameters:

- `inName` Object

#### Returns:

:

## Properties

### `browser`

Object

Get basic browser information

Default: {}

### `compatMode`

String

Document compatMode

Default: "CSS1Compat"

### `documentMode`

Number

Document mode

Default: 0

### `engine`

Object

Get browser's render engine information

Default: {}

### `keyMap`

Object

Get keyboard key code map.

Default: {}

### `os`

Object

Get operating system information

Default: {}

### `prefix`

Array

Get specific prefix

Default: ['webkit','-webkit-']

### `strict`

Boolean

Browser render model CSS1Compat

Default: true

### `strict`

Boolean

If it is secure

Default: false

### `userAgent`

String

User agent string

Default: ""